==> farsight_0.1.10.orig.tar.gz: farsight-0.1.10/farsight/farsight-marshal.h <==

#ifndef __farsight_marshal_MARSHAL_H__
#define __farsight_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT,INT (./farsight-marshal.list:1) */
extern void farsight_marshal_VOID__INT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:INT,STRING (./farsight-marshal.list:2) */
extern void farsight_marshal_VOID__INT_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:STRING,STRING (./farsight-marshal.list:3) */
extern void farsight_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* __farsight_marshal_MARSHAL_H__ */

==> farsight_0.1.28.orig.tar.gz: farsight-0.1.28/farsight/farsight-marshal.h <==

#ifndef __farsight_marshal_MARSHAL_H__
#define __farsight_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT (./farsight-marshal.list:1) */
#define farsight_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:INT,INT (./farsight-marshal.list:2) */
extern void farsight_marshal_VOID__INT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:INT,STRING (./farsight-marshal.list:3) */
extern void farsight_marshal_VOID__INT_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:STRING,STRING (./farsight-marshal.list:4) */
extern void farsight_marshal_VOID__STRING_STRING (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* __farsight_marshal_MARSHAL_H__ */
